@@ -11,27 +11,47 @@
 //! - **`Current`** Ampere (A)
 //! - **`Luminous`** Candela (cd)
 //!
-//! Only mass base unit is different from SI standards for ease of parse.
+//! Only mass base unit is different from the [SI standards] for ease of parse.
+//!
+//! # Dimensionless
+//! This definition defines some hyphen-like letters to represent the dimensionless dimension
+//! because the minus sign (-`\u{002D}`) cannot compose the _Name_.
 //!
 //! # Angle
-//! In this definition, one rotation is defined as one (1).
+//! This definition defines one rotation as one (1).
 //!
 //! # Head
 //! Some units represent pressure as the hight of liquid column.
-//! This definition table defines `Hg`(mercury) and `Aq`(water).
+//! This definition defines `Hg`(mercury) and `Aq`(water).
 //! These units are given Pressure / Length dimension.
-//! So, these units need to be multiplied length unit in order to act as pressure unit.
+//! To use these units for pressure unit, multiply length unit.
 //! (e.g. "mm Hg", "in. Aq")
-//! These units are ordinary written with no space as "mmHg", "inHg".
+//! These units are written with no spaces as "mmHg", "inHg" ordinary.
 //! If these spaces are bothering you, zero width space can help.
 //! (e.g. "mm​Hg", "in.​Aq")
 //!
-//! # Deprecated but acceptable
+//! # Deprecated But Acceptable
 //! Unicode has many curious characters which represent units.
 //! These characters are deprecated because existing only for compatibility.
 //! However, this definition adopts these characters positively.
 //! Why? Just fun, that's all.
 //!
+//! # Illegal But Acceptable
+//! The [SI Standards] does not allow a orphan _Prefix_.
+//! This definition also.
+//! But having said that, **_any_** _Name_ can promote with _Prefix_.
+//! Yes, we can put the _Prefix_ to the dimensionless dimension!
+//! (e.g. "M—" (Mega dimensionless??))
+//! This is useful for expressing notations such as "x10<sup>6</sup>".
+//!
+//! A similar case is a double _Prefix_ , which is not allowed in the [SI Standard].
+//! Of course, the syntax of this package implements disallows it also,
+//! but some CJK compatible characters which represent the unit include a _Prefix_ already.
+//! As a result of this, this definition allows some double prefix.
+//! (e.g. "c㎎" (centi milli gram?? (= 10<sup>-5</sup>g)))
+//! I can't think of a use for it, though.
+//!
+//! [SI Standards]: https://www.bipm.org/en/home
 #![allow(unused_doc_comments)]
 use const_array_attrs::sorted;
 use const_frac::Frac;
@@ -51,8 +71,6 @@ const INCH2METER: Conv = Conv(Frac::from_ratio(254, 1, -4), ZERO);
 const FOOT2INCH: Conv = Conv(Frac::from_int(12), ZERO);
 const YARD2FOOT: Conv = Conv(Frac::from_int(3), ZERO);
 const POUND2GRAM: Conv = Conv(Frac::from_ratio(453_59237, 1, -5), ZERO);
-const MINUTE2SECOND: Conv = Conv(Frac::from_int(60), ZERO);
-const HOUR2MINUTE: Conv = Conv(Frac::from_int(60), ZERO);
 const FIVE_PAR_NINE: Frac = Frac::from_ratio(5, 9, 0);
 const RANKINE2KELVIN: Conv = Conv(FIVE_PAR_NINE, ZERO);
 const FAHRENHEIT2CELSIUS: Conv = Conv(FIVE_PAR_NINE, Frac::from_ratio(32 * 5, 9, 0));
@@ -74,39 +92,35 @@ const PSI2BASE: Conv = POUND2GRAM.mul(GRAM_FORCE2NEWTON).mul(NEWTON2BASE).div(IN
 /// Default unit definition table.
 ///
 #[doc = include_str!("def.md")]
-#[cfg_attr(docsrs, doc(cfg(feature = "default-units")))]
-pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
+pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 231] = [
     // dimensionless
 
     // ‐
     /// `\u{2010}`: Hyphen.
-    /// Some hyphen-like letters are defined to represent the dimensionless dimension
-    /// because the minus (-`\u{002D}`) cannot compose the _Name_.
+    /// (See [Dimensionless](../unit/index.html#dimensionless))
     ("\u{2010}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     // ‒
     /// `\u{2012}`: Figure dash.
-    /// Some hyphen-like letters are defined to represent the dimensionless dimension
-    /// because the minus (-`\u{002D}`) cannot compose the _Name_.
+    /// (See [Dimensionless](../unit/index.html#dimensionless))
     ("\u{2012}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     // –
     /// `\u{2013}`: EN dash.
-    /// Some hyphen-like letters are defined to represent the dimensionless dimension
-    /// because the minus (-`\u{002D}`) cannot compose the _Name_.
+    /// (See [Dimensionless](../unit/index.html#dimensionless))
     ("\u{2013}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     // —
     /// `\u{2014}`: EM DASH.
-    /// Some hyphen-like letters are defined to represent the dimensionless dimension
-    /// because the minus (-`\u{002D}`) cannot compose the _Name_.
+    /// (See [Dimensionless](../unit/index.html#dimensionless))
     ("\u{2014}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     // ―
     /// `\u{2015}`: HORIZONTAL BAR.
-    /// Some hyphen-like letters are defined to represent the dimensionless dimension
-    /// because the minus (-`\u{002D}`) cannot compose the _Name_.
+    /// (See [Dimensionless](../unit/index.html#dimensionless))
     ("\u{2015}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     // ¹
     /// `\u{00B9}`: SUPERSCRIPT ONE.
-    /// "1/s", same as "Hz", cannot accept as unit string because the digit one (1`\u{0031}`) cannot compose the _Name_.
-    /// So, using this superscript one and fraction slash (⁄`\u{2044}`), "1/s" can be written "¹⁄s".
+    ///
+    /// "1/s", same as "Hz", cannot accept as unit string
+    /// because the digit one (1`\u{0031}`) cannot compose the _Name_.
+    /// Using superscript one and fraction slash (⁄`\u{2044}`), "1/s" can be written "¹⁄s".
     /// This character sequence may be displayed more preferable way in most software.
     ("\u{00B9}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     ("%", (Conv(Frac::from_exp10(-2), ZERO), DynDim::new(Dimensionless::CODE))),
@@ -146,7 +160,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     // ㏛
     /// `\u{33DB}`: Steradian in CJK compatibility character.
     ("\u{33DB}", (SR2BASE, DynDim::new(Dimensionless::CODE))),
-    ("rpm", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
+    ("rpm", (Conv(Frac::from_ratio(1, 60, 0), ZERO), DynDim::new(Frequency::CODE))),
     // L
     /// Metre (meter). The base unit of length.
     ("m", (Conv(ONE, ZERO), DynDim::new(Length::CODE))),
@@ -154,30 +168,30 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{334D}`: Meter in CJK compatibility character.
     ("\u{334D}", (Conv(ONE, ZERO), DynDim::new(Length::CODE))),
     // ㌖
-    /// `\u{3316}`: Kilo meter in CJK compatibility character.
+    /// `\u{3316}`: Kilo metre in CJK compatibility character.
     ("\u{3316}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Length::CODE))),
     // ㍷
-    /// `\u{3377}`: Deci meter in CJK compatibility character.
+    /// `\u{3377}`: Deci metre in CJK compatibility character.
     ("\u{3377}", (Conv(Frac::from_exp10(-1), ZERO), DynDim::new(Length::CODE))),
     // ㎙
-    /// `\u{3399}`: Femto meter in CJK compatibility character.
+    /// `\u{3399}`: Femto metre in CJK compatibility character.
     ("\u{3399}", (Conv(Frac::from_exp10(-12), ZERO), DynDim::new(Length::CODE))),
     // ㎚
-    /// `\u{339A}`: Nano meter in CJK compatibility character.
+    /// `\u{339A}`: Nano metre in CJK compatibility character.
     ("\u{339A}", (Conv(Frac::from_exp10(-9), ZERO), DynDim::new(Length::CODE))),
     // ㎛
-    /// `\u{339B}`: Micro meter in CJK compatibility character.
+    /// `\u{339B}`: Micro metre in CJK compatibility character.
     ("\u{339B}", (Conv(Frac::from_exp10(-6), ZERO), DynDim::new(Length::CODE))),
     // ㎜
-    /// `\u{339C}`: Milli meter in CJK compatibility character.
+    /// `\u{339C}`: Milli metre in CJK compatibility character.
     ("\u{339C}", (Conv(Frac::from_exp10(-3), ZERO), DynDim::new(Length::CODE))),
     // ㎝
-    /// `\u{339D}`: Centi meter in CJK compatibility character.
+    /// `\u{339D}`: Centi metre in CJK compatibility character.
     ("\u{339D}", (Conv(Frac::from_exp10(-2), ZERO), DynDim::new(Length::CODE))),
     // ㎞
-    /// `\u{339E}`: Kilo meter in CJK compatibility character.
+    /// `\u{339E}`: Kilo metre in CJK compatibility character.
     ("\u{339E}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Length::CODE))),
-    /// Inch. Because foot (ft.) needs a period, inch also needs it to prevent confusion.
+    /// Inch. The period is needed to prevent recognizing 'min' as milli inch.
     ("in.", (INCH2METER, DynDim::new(Length::CODE))),
     // ㌅
     /// `\u{3305}`: Inch in CJK compatibility character.
@@ -185,12 +199,12 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     // ㏌
     /// `\u{33CC}`: Inch in CJK compatibility character.
     ("\u{33CC}", (INCH2METER, DynDim::new(Length::CODE))),
-    /// Period is needed to prevent conflicting with femto ton (ft)
+    /// The period is needed to prevent conflicting with femto ton (ft)
     ("ft.", (FOOT2INCH.then(INCH2METER), DynDim::new(Length::CODE))),
     // ㌳
     /// `\u{3333}`: Foot in CJK compatibility character.
     ("\u{3333}", (FOOT2INCH.then(INCH2METER), DynDim::new(Length::CODE))),
-    /// Yard. The period is needed the exact reason of inch's one.
+    /// Yard. Because foot and inch need a period, the yard also requires it to prevent confusion.
     ("yd.", (YARD2FOOT.then(FOOT2INCH).then(INCH2METER), DynDim::new(Length::CODE))),
     // ㍎
     /// `\u{334E}`: Yard in CJK compatibility character.
@@ -199,10 +213,10 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{334F}`: Yard in CJK compatibility character.
     ("\u{334F}", (YARD2FOOT.then(FOOT2INCH).then(INCH2METER), DynDim::new(Length::CODE))),
     // Å
-    /// `\u{00C5}`: Angstrom
+    /// `\u{00C5}`: [Angstrom](https://en.wikipedia.org/wiki/Angstrom)
     ("\u{00C5}", (Conv(Frac::from_exp10(-10), ZERO), DynDim::new(Length::CODE))),
     // Å
-    /// `\u{212B}`: Angstrom
+    /// `\u{212B}`: [Angstrom](https://en.wikipedia.org/wiki/Angstrom)
     ("\u{212B}", (Conv(Frac::from_exp10(-10), ZERO), DynDim::new(Length::CODE))),
     // ㌋
     /// `\u{330B}`: Nautical mile in CJK compatibility character.
@@ -232,7 +246,8 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{3373}`: [Astronomical unit](https://en.wikipedia.org/wiki/Astronomical_unit) in CJK compatibility character.
     ("\u{3373}", (Conv(Frac::from_int(149_597_870_700), ZERO), DynDim::new(Length::CODE))),
     /// [Parsec](https://en.wikipedia.org/wiki/Parsec).
-    ("pc", (
+    /// The period is needed to prevent conflicting the light speed (`c`).
+    ("pc.", (
         Conv(Frac::from_ratio(3_085_677_581, 1, 7), ZERO),
         DynDim::new(Length::CODE)
     )),
@@ -244,8 +259,8 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     )),
     // M
     /// Gram. The base unit of mass.
-    /// In SI unit system, the base unit of mass is kilo gram (kg).
-    /// But this default definition table uses the gram (g) for ease of parse.
+    /// The [SI Standards] adopts the kilogram (kg) as the base unit of mass.
+    /// But this definition adopts the gram (g) for ease of parse.
     ("g", (Conv(ONE, ZERO), DynDim::new(Mass::CODE))),
     // ㌘
     /// `\u{3318}`: Gram in CJK compatibility character.
@@ -273,7 +288,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{334C}`: Megatonne in CJK compatibility character.
     ("\u{334C}", (Conv(Frac::from_exp10(9), ZERO), DynDim::new(Mass::CODE))),
     /// [Dalton](https://en.wikipedia.org/wiki/Dalton_(unit)).
-    /// `u`(unified atomic mass unit) is excluded to prevent conflicting
+    /// This definition exclude `u`(unified atomic mass unit) to prevent conflicting
     /// [Astronomical unit](https://en.wikipedia.org/wiki/Astronomical_unit) (`au`).
     ("Da", (
         Conv(Frac::from_ratio(1_660_539_066_60, 1, -35), ZERO),
@@ -369,7 +384,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// The base unit of electric current.
     ("A", (Conv(ONE, ZERO), DynDim::new(Current::CODE))),
     // ㌂
-    /// Ampere in CJK compatibility character.
+    /// `\u{3302}`: Ampere in CJK compatibility character.
     ("\u{3302}", (Conv(ONE, ZERO), DynDim::new(Current::CODE))),
     // ㎀
     /// `\u{3380}`: Pico ampere in CJK compatibility character.
@@ -387,7 +402,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{3384}`: Kilo ampere in CJK compatibility character.
     ("\u{3384}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Current::CODE))),
     // ㏟
-    /// `\u{33DF}`: Ampere par meter in CJK compatibility character.
+    /// `\u{33DF}`: Ampere par metre in CJK compatibility character.
     ("\u{33DF}", (Conv(ONE, ZERO), DynDim::new(MagneticFieldStrength::CODE))),
     // J
     /// [Candela](https://en.wikipedia.org/wiki/Candela).
@@ -443,7 +458,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{331F}`: Cycle in CJK compatibility character.
     ("\u{331F}", (Conv(ONE, ZERO), DynDim::new(Dimensionless::CODE))),
     // ㎮
-    /// `\u{33AE}`: red/s in CJK compatibility character.
+    /// `\u{33AE}`: rad/s in CJK compatibility character.
     ("\u{33AE}", (RAD2BASE, DynDim::new(Frequency::CODE))),
     // ㎯
     /// `\u{33AF}`: rad/s<sup>2</sup> in CJK compatibility character.
@@ -474,7 +489,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{3303}`: Are in CJK compatibility character.
     ("\u{3303}", (Conv(Frac::from_exp10(2), ZERO), DynDim::new(Area::CODE))),
     // ㌶
-    /// `\u{3336}`: Hecto are in CJK compatibility charactor.
+    /// `\u{3336}`: Hecto are in CJK compatibility character.
     ("\u{3336}", (Conv(Frac::from_exp10(4), ZERO), DynDim::new(Area::CODE))),
     // ㏊
     /// `\u{33CA}`: Hecto are in CJK compatibility character.
@@ -558,19 +573,19 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// The speed of light in vacuum.
     ("c", (Conv(Frac::from_int(299_792_458), ZERO), DynDim::new(Velocity::CODE))),
     /// The speed of light in vacuum.
-    /// Combining with time unit, astronomical length can be described.
+    /// This can describe astronomical length by combining with time units.
     /// (e.g. "light year")
     ("light", (Conv(Frac::from_int(299_792_458), ZERO), DynDim::new(Velocity::CODE))),
     // 光
     /// `\u{5149}`: The speed of light in vacuum.
-    /// Combining with time unit, astronomical length can be described.
-    /// Since a space character is not ordinary used to delimit word in hanji (kanji),
-    /// zero width space is suitable for this use. (e.g. 光​年)
+    /// This can describe astronomical length by combining with time units.
+    /// Hanji (kanji) does not use a space character to delimit word ordinary.
+    /// Zero width space is suitable for this use. (e.g. 光​年)
     ("\u{5149}", (Conv(Frac::from_int(299_792_458), ZERO), DynDim::new(Velocity::CODE))),
     // ㎧
     /// `\u{33A7}`: m/s in CJK compatibility character.
     ("\u{33A7}", (Conv(ONE, ZERO), DynDim::new(Velocity::CODE))),
-    /// Knot. "kt" is excluded in this definition to prevent conflicting with kilo ton (kt).
+    /// Knot. This definition exclude `kt` to prevent conflicting with kilo ton (kt).
     ("kn", (Conv(Frac::from_ratio(1852, 3600, 0), ZERO), DynDim::new(Velocity::CODE))),
     // ㌩
     /// `\u{3329}`: Knot in CJK compatibility character.
@@ -640,15 +655,15 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     ("psia", (PSI2BASE,DynDim::new(Pressure::CODE))),
     /// Gaged pound force per square inch (lbf/in.<sup>2</sup>\[gage\]).
     ("psig", (Conv(PSI2BASE.0, Frac::from_int(101325000)), DynDim::new(Pressure::CODE))),
-    /// Pressure based mercury head. lacked length dimension. (see [Head](#head))
+    /// Pressure based mercury head. lacked length dimension. (see [Head](../unit/index.html#head))
     ("Hg", (Conv(Frac::from_ratio(101325, 760, 3), ZERO), DynDim::new(Head::CODE))),
     // ㋌
-    /// `\u{32CC}`: Hg in CJK compatibility character. (see [Head](#head))
+    /// `\u{32CC}`: Hg in CJK compatibility character. (see [Head](../unit/index.html#head))
     ("\u{32CC}", (
         Conv(Frac::from_ratio(101325, 760, 3), ZERO),
         DynDim::new(Head::CODE)
     )),
-    /// Pressure based water head. lacked length dimension. (see [Head](#head))
+    /// Pressure based water head. lacked length dimension. (see [Head](../unit/index.html#head))
     ("Aq", (Conv(Frac::from_int(9806650), ZERO), DynDim::new(Head::CODE))),
     // Energy
     /// [Joule](https://en.wikipedia.org/wiki/Joule).
@@ -674,8 +689,6 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     )),
     /// [British thermal unit](https://en.wikipedia.org/wiki/British_thermal_unit).
     ("Btu", (BTU2CALORIE.then(CALORIE2JOULE).then(JOULE2BASE), DynDim::new(Energy::CODE))),
-    /// Watt hour.
-    ("Wh", (WATT2BASE.mul(HOUR2MINUTE.then(MINUTE2SECOND)), DynDim::new(Energy::CODE))),
     /// [Erg](https://en.wikipedia.org/wiki/Erg).
     ("erg", (Conv(Frac::from_exp10(-4), ZERO), DynDim::new(Energy::CODE))),
     // ㋍
@@ -753,7 +766,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// `\u{33DE}`: V/m in CJK compatibility character.
     ("\u{33DE}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(ElectricFieldStrength::CODE))),
     // ㌾
-    // `\u{333E}`: Volt in CJK compatibility character.
+    /// `\u{333E}`: Volt in CJK compatibility character.
     ("\u{333E}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Voltage::CODE))),
     // ㎴
     /// `\u{33B4}`: Pico volt in CJK compatibility character.
@@ -792,7 +805,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     /// [Siemens](https://en.wikipedia.org/wiki/Siemens_(unit)).
     ("S", (Conv(Frac::from_exp10(-3), ZERO), DynDim::new(ElectricConductance::CODE))),
     // ℧
-    /// [Siemens](https://en.wikipedia.org/wiki/Siemens_(unit)).
+    /// `\u{2127}`: [Siemens](https://en.wikipedia.org/wiki/Siemens_(unit)).
     ("\u{2127}", (Conv(Frac::from_exp10(-3), ZERO), DynDim::new(ElectricConductance::CODE))),
     /// [Henry](https://en.wikipedia.org/wiki/Henry_(unit)).
     ("H", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(ElectricalInductance::CODE))),
@@ -826,7 +839,7 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 232] = [
     ("T", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(MagneticFluxDensity::CODE))),
     /// [Poise](https://en.wikipedia.org/wiki/Poise_(unit)).
     ("P", (Conv(Frac::from_exp10(2), ZERO), DynDim::new(Viscosity::CODE))),
-    /// [stokes](https://en.wikipedia.org/wiki/Stokes_(unit)).
+    /// [Stokes](https://en.wikipedia.org/wiki/Stokes_(unit)).
     ("St", (Conv(Frac::from_exp10(-4), ZERO), DynDim::new(KinematicViscosity::CODE))),
 ];
 
